// Sample code: Initialize the SDK using FULL model, load two images, extract feature vectors and compare the similarity
// This sample is similar to face_recognition.cpp, and shows how to initialize the SDK using the FULL model (default is LITE model).
// First two images of Neil Armstrong are compared. Then the similarity score of Neil Armstrong with Buzz Aldrin is computed.
// Build on Linux: g++ -o face_recognition_full_model --std=c++11 ./face_recognition_full_model.cpp -I ../ -L ../trueface_sdk -l tf -fopenmp
// Build on macOS: g++ -o face_recognition_full_model --std=c++11 ./face_recognition_full_model.cpp -I ../ -L ../trueface_sdk -l tf

#include "trueface_sdk/tf_sdk.h"
#include <iostream>
#include <vector>

int main() {
    Trueface::ConfigurationOptions options;
    options.frModel = Trueface::FacialRecognitionModel::FULL;

    Trueface::SDK tfSdk(options);
    // TODO: replace the string with your license code.
    bool valid = tfSdk.setLicense("${LICENSE_CODE}");
    
    if (valid == false) {
        std::cout<<"Error: the provided license is invalid."<<std::endl;
        return 1;
    }

    // Load the first Armstrong image and extract the feature vector.
    Trueface::ErrorCode errorCode = tfSdk.setImage("../images/armstrong_1.jpg");
    if (errorCode != Trueface::ErrorCode::NO_ERROR) {
        std::cout<<"Error: could not load the image"<<std::endl;
        return 1;
    }

    Trueface::Faceprint faceprint1;
    errorCode = tfSdk.getLargestFaceFeatureVector(faceprint1);
    if (errorCode != Trueface::ErrorCode::NO_ERROR) {
        std::cout<<"Error: SDK not built with FULL facial recognition model"<<std::endl;
        return 0;
    }

    // Load the second Armstrong image and extract the feature vector.
    errorCode = tfSdk.setImage("../images/armstrong_2.jpg");
    if (errorCode != Trueface::ErrorCode::NO_ERROR) {
        std::cout<<"Error: could not load the image 2"<<std::endl;
        return 1;
    }

    Trueface::Faceprint faceprint2;
    tfSdk.getLargestFaceFeatureVector(faceprint2);

    // Compute the similarity between the two Armstrong face images.
    float similarityScore;
    float matchProbability;
    tfSdk.getSimilarity(faceprint1, faceprint2, matchProbability, similarityScore);

    std::cout<<"Similarity score of armstrong_1 - armstrong_2: "<<similarityScore<<std::endl;
    std::cout<<"Match probability of armstrong_1 - armstrong_2: "<<matchProbability<<std::endl;

    // Load the Aldrin image and extract the feature vector.
    errorCode = tfSdk.setImage("../images/aldrin.jpg");
    if (errorCode != Trueface::ErrorCode::NO_ERROR) {
        std::cout<<"Error: could not load the image 2"<<std::endl;
        return 1;
    }

    Trueface::Faceprint faceprint3;
    tfSdk.getLargestFaceFeatureVector(faceprint3);

    // Compute the similarity between the Armstrong and Aldrin face images.
    tfSdk.getSimilarity(faceprint1, faceprint3, matchProbability, similarityScore);

    std::cout<<"Similarity score of armstrong_1 - aldrin: "<<similarityScore<<std::endl;
    std::cout<<"Match probability of armstrong_1 - aldrin: "<<matchProbability<<std::endl;

    return 0;
}