// Sample code: sets an image and runs spoof detection on the image

// This sample demonstrates how to use the spoof detector to identify presentation attacks.
// First, the image is set. Next, the spood detection function is used to identify potential spoof.
// Build on Linux: g++ -o spoof_detection --std=c++11 ./spoof_detection.cpp -I ../ -L ../trueface_sdk -l tf -fopenmp
// Build on macOS: g++ -o spoof_detection --std=c++11 ./spoof_detection.cpp -I ../ -L ../trueface_sdk -l tf


#include "trueface_sdk/tf_sdk.h"
#include <iostream>

int main() {
    Trueface::SDK tfSdk;
    // TODO: replace the string with your license code.
    bool valid = tfSdk.setLicense("${LICENSE_CODE}");

    if (valid == false) {
        std::cout << "Error: the provided license is invalid." << std::endl;
        return 1;
    }

    // Load the real image
    Trueface::ErrorCode errorCode = tfSdk.setImage("../images/real.jpg");
    if (errorCode != Trueface::ErrorCode::NO_ERROR) {
        std::cout << "Error: could not load the image" << std::endl;
        return 1;
    }

    std::cout << "Running spoof detection with real image" << std::endl;

    Trueface::SpoofLabel result;
    float spoofScore;
    errorCode = tfSdk.detectSpoof(result, spoofScore);
    if (errorCode != Trueface::ErrorCode::NO_ERROR) {
        std::cout << "Error: could not run spoof detection" << std::endl;
        return 1;
    }

    if (result == Trueface::SpoofLabel::REAL) {
        std::cout << "Real image detected" << std::endl;
    } else {
        std::cout << "Fake image detected" << std::endl;
    }

    // Load the fake image
    errorCode = tfSdk.setImage("../images/fake.jpg");
    if (errorCode != Trueface::ErrorCode::NO_ERROR) {
        std::cout << "Error: could not load the image" << std::endl;
        return 1;
    }

    std::cout << "Running spoof detection with fake image" << std::endl;

    errorCode = tfSdk.detectSpoof(result, spoofScore);
    if (errorCode != Trueface::ErrorCode::NO_ERROR) {
        std::cout << "Error: could not run spoof detection" << std::endl;
        return 1;
    }

    if (result == Trueface::SpoofLabel::REAL) {
        std::cout << "Real image detected" << std::endl;
    } else {
        std::cout << "Fake image detected" << std::endl;
    }

    return 0;
}