# Sample code: Create a memory-only collection, enroll multiple images belonging to different identities, then run 1 to N identification

import tfsdk
import os
options = tfsdk.ConfigurationOptions()
# Can set configuration options here

options.dbms = tfsdk.DATABASEMANAGEMENTSYSTEM.NONE # The data will not persist

# To have the collection data persist after application termination, use the SQLITE backend option
# options.dbms = tfsdk.DATABASEMANAGEMENTSYSTEM.SQLITE

sdk = tfsdk.SDK(options)

# TODO: export your license token as TRUEFACE_TOKEN environment variable
is_valid = sdk.set_license(os.environ['TRUEFACE_TOKEN'])
if (is_valid == False):
	print("Invalid License Provided")
	print("Be sure to export your license token as TRUEFACE_TOKEN")
	quit()

# If we are using a database backend, need to first call create_database_connection
# Since we are using DATABASEMANAGEMENTSYSTEM.NONE this is not necessary

# Create a new collection
res = sdk.create_load_collection("my_collection")
if (res != tfsdk.ERRORCODE.NO_ERROR):
	print("Unable to create collection")
	quit()

# Some identities to populate into our collection
image_identities = [
	("../images/armstrong_2.jpg", "Armstrong"),
	("../images/armstrong_3.jpg", "Armstrong"), # Can add the same identity more than once
	("../images/aldrin.jpg", "Aldrin")
]

for path, identity in image_identities:
	# Generate a template for each image
	res = sdk.set_image(path)
	if (res != tfsdk.ERRORCODE.NO_ERROR):
		print("Unable to set image at path:", path)
		continue

	# Extract the feature vector
	res, v = sdk.get_largest_face_feature_vector()
	if (res != tfsdk.ERRORCODE.NO_ERROR):
		print("Unable to generate feature vector")
		continue

	# Enroll the feature vector into the collection
	res, UUID = sdk.enroll_template(v, identity)
	if (res != tfsdk.ERRORCODE.NO_ERROR):
		print("Unable to enroll feature vector")
		continue

	# TODO: Can store the UUID for later use
	print("Success, enrolled template with UUID:", UUID)

# Use a new image of Armstrong as the probe
res = sdk.set_image("../images/armstrong_1.jpg")
if (res != tfsdk.ERRORCODE.NO_ERROR):
	print("Unable to set image")
	quit()

# Extract the feature vector
res, v1 = sdk.get_largest_face_feature_vector()
if (res != tfsdk.ERRORCODE.NO_ERROR):
	print("Unable to generate feature vector")
	quit()

# Run identification query using threshold of 0.3
res, found, candidate = sdk.identify_top_candidate(v1, 0.3)

if found == False:
	print("Unable to find match above threshold")
else:
	print("Match found!")
	print("Identity:", candidate.identity)
	print("Match Probability:", candidate.match_probability)
	print("Similarity:", candidate.similarity_measure)




